<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="sr_RS">
<context>
    <name>AppMgmtDialog</name>
    <message>
        <location filename="../dialogs.cpp" line="1303"/>
        <source>Manage External Applications</source>
        <translation>Управљај екстерним апликацијама</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="1315"/>
        <source>Name</source>
        <translation>Име</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="1317"/>
        <source>Application path and arguments</source>
        <translation>Путања и аргументи апликације</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="1323"/>
        <source>Choose</source>
        <translation>Изабери</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="1327"/>
        <source>Add manually</source>
        <translation>Додај ручно</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="1331"/>
        <source>Remove</source>
        <translation>Уклони</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="1338"/>
        <source>OK</source>
        <translation>Уреду</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="1378"/>
        <source>Choose Application</source>
        <translation>Изабери апликацију</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="1390"/>
        <source>New Application</source>
        <translation>Нова апликација</translation>
    </message>
</context>
<context>
    <name>ColorsDialog</name>
    <message>
        <location filename="../dialogs.cpp" line="1008"/>
        <source>Colors</source>
        <translation>Боје</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="1014"/>
        <source>Reset</source>
        <translation>Поврати</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="1019"/>
        <source>OK</source>
        <translation>Уреду</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="1027"/>
        <source>Hue</source>
        <translation>Нијанса</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="1028"/>
        <source>Saturation</source>
        <translation>Засићеност</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="1029"/>
        <source>Lightness</source>
        <translation>Светлина</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="1038"/>
        <source>Colorize</source>
        <translation>Обоји</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="1042"/>
        <location filename="../dialogs.cpp" line="1046"/>
        <location filename="../dialogs.cpp" line="1050"/>
        <source>Negative</source>
        <translation>Негатив</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="1069"/>
        <location filename="../dialogs.cpp" line="1135"/>
        <source>Red</source>
        <translation>Црвена</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="1074"/>
        <location filename="../dialogs.cpp" line="1143"/>
        <source>Green</source>
        <translation>Зелена</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="1079"/>
        <location filename="../dialogs.cpp" line="1151"/>
        <source>Blue</source>
        <translation>Плава</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="1096"/>
        <source>Hue and Saturation</source>
        <translation>Нијанса и засићеност</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="1102"/>
        <source>Affected Channels</source>
        <translatorcomment>Popravi</translatorcomment>
        <translation>Погођени канали</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="1106"/>
        <source>Brightness</source>
        <translation>Светлост</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="1107"/>
        <source>Contrast</source>
        <translation>Контраст</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="1131"/>
        <source>Brightness and Contrast</source>
        <translation>Светлост и контраст</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="1171"/>
        <source>Color Balance</source>
        <translation>Баланс боја</translation>
    </message>
</context>
<context>
    <name>CopyMoveToDialog</name>
    <message>
        <location filename="../dialogs.cpp" line="1407"/>
        <source>Move to...</source>
        <translation>Помери у...</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="1410"/>
        <source>Copy to...</source>
        <translation>Копирај у...</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="1438"/>
        <source>Browse...</source>
        <translation>Прегледај...</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="1440"/>
        <source>Remove</source>
        <translation>Уклони</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="1447"/>
        <source>Cancel</source>
        <translation>Откажи</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="1452"/>
        <source>OK</source>
        <translation>Уреду</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="1463"/>
        <location filename="../dialogs.cpp" line="1489"/>
        <source>Destination:</source>
        <translation>Дестинација:</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="1529"/>
        <source>Choose Folder</source>
        <translation>Изабери фасциклу</translation>
    </message>
</context>
<context>
    <name>CpMvDialog</name>
    <message>
        <location filename="../dialogs.cpp" line="28"/>
        <source>Cancel</source>
        <translation>Откажи</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="113"/>
        <location filename="../dialogs.cpp" line="141"/>
        <source>Copying &quot;%1&quot; to &quot;%2&quot;.</source>
        <translation>Копирам &quot;%1&quot; у &quot;%2&quot;.</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="113"/>
        <location filename="../dialogs.cpp" line="142"/>
        <source>Moving &quot;%1&quot; to &quot;%2&quot;.</source>
        <translation>Померам &quot;%1&quot; у &quot;%2&quot;.</translation>
    </message>
</context>
<context>
    <name>CropDialog</name>
    <message>
        <location filename="../dialogs.cpp" line="688"/>
        <source>Cropping</source>
        <translation>Изрежи</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="696"/>
        <source>Reset</source>
        <translation>Поврати</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="699"/>
        <source>OK</source>
        <translation>Уреду</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="735"/>
        <source>Left</source>
        <translation>Лево</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="736"/>
        <source>Right</source>
        <translation>Десно</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="737"/>
        <source>Top</source>
        <translation>Горе</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="738"/>
        <source>Bottom</source>
        <translation>Доле</translation>
    </message>
</context>
<context>
    <name>ImageTags</name>
    <message>
        <location filename="../tags.cpp" line="36"/>
        <source>Image Tags</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../tags.cpp" line="37"/>
        <source>Filter</source>
        <translation type="unfinished">Филтер</translation>
    </message>
    <message>
        <location filename="../tags.cpp" line="59"/>
        <source>Tag</source>
        <translation>Означи</translation>
    </message>
    <message>
        <location filename="../tags.cpp" line="63"/>
        <source>Untag</source>
        <translation>Уклони ознаку</translation>
    </message>
    <message>
        <location filename="../tags.cpp" line="66"/>
        <source>New Tag</source>
        <translation>Нова ознака</translation>
    </message>
    <message>
        <location filename="../tags.cpp" line="70"/>
        <source>Remove Tag</source>
        <translation>Уклони ознаку</translation>
    </message>
    <message>
        <location filename="../tags.cpp" line="73"/>
        <source>Clear Filters</source>
        <translation>Уклони филтере</translation>
    </message>
    <message>
        <location filename="../tags.cpp" line="77"/>
        <source>Negate</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../tags.cpp" line="179"/>
        <location filename="../tags.cpp" line="482"/>
        <location filename="../tags.cpp" line="491"/>
        <source>Error</source>
        <translation>Грешка</translation>
    </message>
    <message>
        <location filename="../tags.cpp" line="179"/>
        <source>Failed to save tags to </source>
        <translation>Неуспело снимање ознаке</translation>
    </message>
    <message>
        <location filename="../tags.cpp" line="381"/>
        <source>Tagging </source>
        <translation>Означивање</translation>
    </message>
    <message>
        <location filename="../tags.cpp" line="384"/>
        <source>Untagging </source>
        <translation>Уклањање ознака</translation>
    </message>
    <message>
        <location filename="../tags.cpp" line="473"/>
        <source>Add a new tag</source>
        <translation>Додај нову ознаку</translation>
    </message>
    <message>
        <location filename="../tags.cpp" line="474"/>
        <source>Enter new tag name</source>
        <translation>Унеси име ознаке</translation>
    </message>
    <message>
        <location filename="../tags.cpp" line="482"/>
        <source>No name entered</source>
        <translation>Име није унесено</translation>
    </message>
    <message>
        <location filename="../tags.cpp" line="491"/>
        <source>Tag </source>
        <translation>Ознака</translation>
    </message>
    <message>
        <location filename="../tags.cpp" line="491"/>
        <source> already exists</source>
        <translation>Већ постоји</translation>
    </message>
    <message>
        <location filename="../tags.cpp" line="508"/>
        <source>Remove selected tags(s)?</source>
        <translation>Уклони изабрану ознаку(е)?</translation>
    </message>
    <message>
        <location filename="../tags.cpp" line="509"/>
        <source>Remove tag</source>
        <translation>Уклони ознаку</translation>
    </message>
    <message>
        <location filename="../tags.cpp" line="514"/>
        <source>Yes</source>
        <translation>Да</translation>
    </message>
    <message>
        <location filename="../tags.cpp" line="515"/>
        <source>Cancel</source>
        <translation>Откажи</translation>
    </message>
</context>
<context>
    <name>ImageView</name>
    <message>
        <location filename="../imageview.cpp" line="626"/>
        <source>Clipboard</source>
        <translation>Клиборд</translation>
    </message>
    <message>
        <location filename="../imageview.cpp" line="780"/>
        <source>Selection size: </source>
        <translation>Величина селекције:</translation>
    </message>
    <message>
        <location filename="../imageview.cpp" line="828"/>
        <source>No selection</source>
        <translation>Без селекције</translation>
    </message>
    <message>
        <location filename="../imageview.cpp" line="828"/>
        <source>Hold down the Ctrl key and select a region using the mouse.</source>
        <translation>Држи Ctrl дугме притиснуто и изабери регију користећи миш.</translation>
    </message>
    <message>
        <location filename="../imageview.cpp" line="958"/>
        <source>Saving...</source>
        <translation>Снимам...</translation>
    </message>
    <message>
        <location filename="../imageview.cpp" line="975"/>
        <location filename="../imageview.cpp" line="988"/>
        <location filename="../imageview.cpp" line="1021"/>
        <source>Error</source>
        <translation>Грешка</translation>
    </message>
    <message>
        <location filename="../imageview.cpp" line="975"/>
        <location filename="../imageview.cpp" line="1021"/>
        <source>Failed to save image.</source>
        <translation>Грешка при снимању слике.</translation>
    </message>
    <message>
        <location filename="../imageview.cpp" line="988"/>
        <source>Failed to save Exif metadata.</source>
        <translation>Грешка при снимању Exif података.</translation>
    </message>
    <message>
        <location filename="../imageview.cpp" line="993"/>
        <location filename="../imageview.cpp" line="1034"/>
        <source>Image saved.</source>
        <translation>Слика снимљена.</translation>
    </message>
    <message>
        <location filename="../imageview.cpp" line="1005"/>
        <source>Save image as</source>
        <translation>Сними слику као</translation>
    </message>
    <message>
        <location filename="../imageview.cpp" line="1007"/>
        <source>Images</source>
        <translation>Слике</translation>
    </message>
</context>
<context>
    <name>InfoView</name>
    <message>
        <location filename="../infoview.cpp" line="40"/>
        <source>Copy</source>
        <translation>Копирај</translation>
    </message>
</context>
<context>
    <name>Phototonic</name>
    <message>
        <location filename="../mainwindow.cpp" line="117"/>
        <source>Image Info</source>
        <translation>Информације о слици</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="200"/>
        <location filename="../mainwindow.cpp" line="201"/>
        <source>Zoom</source>
        <translation>Уближи</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="212"/>
        <location filename="../mainwindow.cpp" line="213"/>
        <source>Mirroring</source>
        <translatorcomment>Ово треба поправити</translatorcomment>
        <translation>Преслика (огледало)</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="223"/>
        <location filename="../mainwindow.cpp" line="224"/>
        <source>Transform</source>
        <translation>Трансформиши</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="252"/>
        <location filename="../mainwindow.cpp" line="253"/>
        <location filename="../mainwindow.cpp" line="801"/>
        <source>View</source>
        <translation>Поглед</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="276"/>
        <source>Top</source>
        <translation>Горе</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="281"/>
        <source>Bottom</source>
        <translation>Доле</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="286"/>
        <source>Close Image</source>
        <translation>Затвори слику</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="290"/>
        <source>Full Screen</source>
        <translation>Приказ преко целог екрана</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="295"/>
        <source>Preferences</source>
        <translation>Поставке</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="300"/>
        <source>Exit</source>
        <translation>Изађи</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="304"/>
        <source>Enlarge Thumbnails</source>
        <translation>Повећај минијатурне приказе</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="311"/>
        <source>Shrink Thumbnails</source>
        <translation>Уманњи минијатурне приказе</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="318"/>
        <source>Cut</source>
        <translation>Изрежи</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="324"/>
        <source>Copy</source>
        <translation>Копирај</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="330"/>
        <source>Copy to...</source>
        <translation>Копирај у...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="334"/>
        <source>Move to...</source>
        <translation>Помери у...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="338"/>
        <source>Delete</source>
        <translation>Избриши</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="343"/>
        <source>Save</source>
        <translation>Сними</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="347"/>
        <source>Save As</source>
        <translation>Сними као</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="351"/>
        <source>Copy Image Data</source>
        <translation>Копирај податке слике</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="353"/>
        <source>Paste Image Data</source>
        <translation>Налепи податке слике</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="356"/>
        <location filename="../mainwindow.cpp" line="3151"/>
        <source>Rename</source>
        <translation>Преименуј</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="360"/>
        <source>Select All</source>
        <translation>Означи све</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="364"/>
        <location filename="../mainwindow.cpp" line="1069"/>
        <source>About</source>
        <translation>О</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="370"/>
        <source>Name</source>
        <translation>Име</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="372"/>
        <source>Time</source>
        <translation>Време</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="374"/>
        <source>Size</source>
        <translation>Величина</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="376"/>
        <source>Type</source>
        <translation>Тип</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="378"/>
        <source>Reverse</source>
        <translation>Обрни</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="401"/>
        <source>Show Hidden Files</source>
        <translation>Прикажи скривене датотеке</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="407"/>
        <source>Show Labels</source>
        <translation>Прикажи натписе</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="414"/>
        <source>Small Icons</source>
        <translation>Мале иконе</translation>
    </message>
    <message>
        <source>Hide Docks Title Bar</source>
        <translation type="vanished">Сакриј насловну траку сидрене траке</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="420"/>
        <source>Hide Dock Title Bars</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="426"/>
        <source>Show Toolbar</source>
        <translation>Прикажи алатну траку</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="432"/>
        <source>Classic Thumbs</source>
        <translation>Класичне минијатурне слике</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="434"/>
        <source>Compact</source>
        <translation>Компактно</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="436"/>
        <source>Squarish</source>
        <translation>Коцкасто</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="448"/>
        <source>Reload</source>
        <translation>Учитај поново</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="453"/>
        <source>Include Sub-folders</source>
        <translation>Укључи под-фасцикле</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="459"/>
        <source>Paste Here</source>
        <translation>Налепи овде</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="465"/>
        <source>New Folder</source>
        <translation>Нова фасцикла</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="470"/>
        <source>Back</source>
        <translation>Назад</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="476"/>
        <source>Forward</source>
        <translation>Напред</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="482"/>
        <source>Go Up</source>
        <translation>Иди горе</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="487"/>
        <source>Home</source>
        <translation>Почетна</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="492"/>
        <location filename="../mainwindow.cpp" line="2717"/>
        <source>Slide Show</source>
        <translation>Слајд приказ</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="497"/>
        <source>Next</source>
        <translation>Следећa</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="502"/>
        <source>Previous</source>
        <translation>Прошла</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="507"/>
        <source>First</source>
        <translation>Прва</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="512"/>
        <source>Last</source>
        <translation>Задња</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="517"/>
        <source>Random</source>
        <translation>Насумична</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="521"/>
        <source>Open</source>
        <translation>Отвори</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="526"/>
        <source>Load Clipboard</source>
        <translation>Учитај клипборд</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="531"/>
        <location filename="../mainwindow.cpp" line="532"/>
        <source>Open With...</source>
        <translation>Отвори помоћу...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="535"/>
        <source>Manage External Applications</source>
        <translation>Управљај екстерним апликацијама</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="539"/>
        <source>Add Bookmark</source>
        <translation>Додај кратицу</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="544"/>
        <source>Remove Bookmark</source>
        <translation>Уклони кратицу</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="548"/>
        <source>Zoom Out</source>
        <translation>Удаљи</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="553"/>
        <source>Zoom In</source>
        <translation>Уближи</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="558"/>
        <source>Reset Zoom</source>
        <translation>Поврати зум</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="563"/>
        <location filename="../mainwindow.cpp" line="1424"/>
        <source>Original Size</source>
        <translation>Оригинална величина</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="568"/>
        <source>Keep Zoom</source>
        <translation>Задржи зум</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="573"/>
        <source>Rotate 90 degree CCW</source>
        <translation>Ротирај 90 степени супротно казаљци</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="578"/>
        <source>Rotate 90 degree CW</source>
        <translation>Ротирај 90 степени у смеру казаљке</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="583"/>
        <source>Flip Horizontally</source>
        <translation>Обрни хоризонтално</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="588"/>
        <source>Flip Vertically</source>
        <translation>Обрни вертикално</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="593"/>
        <source>Cropping</source>
        <translation>Изрежи</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="598"/>
        <source>Crop to Selection</source>
        <translation>Изрежи селекцију</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="602"/>
        <source>Scale Image</source>
        <translation>Промени величину слике</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="607"/>
        <source>Rotate 1 degree CCW</source>
        <translation>Ротирај 1 степен супротно казаљци</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="611"/>
        <source>Rotate 1 degree CW</source>
        <translation>ротирај 1 степен у смеру казаљке</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="615"/>
        <source>Colors</source>
        <translation>Боје</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="620"/>
        <source>Find Duplicate Images</source>
        <translation>Пронађи дупле слике</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="626"/>
        <source>Disable</source>
        <translation>Искључено</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="628"/>
        <source>Dual</source>
        <translation>Двоструко</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="630"/>
        <source>Triple</source>
        <translation>Троструко</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="632"/>
        <source>Dual Vertical</source>
        <translation>Двоструко вертикално</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="634"/>
        <source>Quad</source>
        <translation>Четвероструко</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="649"/>
        <source>Lock Transformations</source>
        <translation>Закључај трансформације</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="654"/>
        <source>Move Left</source>
        <translation>Помери лево</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="657"/>
        <source>Move Right</source>
        <translation>Помери десно</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="660"/>
        <source>Move Up</source>
        <translation>Помери горе</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="663"/>
        <source>Move Down</source>
        <translation>Помери доле</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="667"/>
        <source>Invert Selection</source>
        <translation>Обрни селекцију</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="671"/>
        <source>Filter by Name</source>
        <translation>Филтрирај по имену</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="674"/>
        <source>Set Path</source>
        <translation>Постави путању</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="681"/>
        <source>&amp;File</source>
        <translation>&amp;Фајл</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="689"/>
        <source>&amp;Edit</source>
        <translation>&amp;Уреди</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="705"/>
        <source>&amp;Go</source>
        <translation>&amp;Иди</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="714"/>
        <source>&amp;View</source>
        <translation>&amp;Поглед</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="720"/>
        <source>Sort By</source>
        <translation>Сортирај по</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="743"/>
        <source>&amp;Tools</source>
        <translation>&amp;Алати</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="747"/>
        <source>&amp;Help</source>
        <translation>&amp;Помоћ</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="771"/>
        <source>Edit</source>
        <translation>Уреди</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="781"/>
        <source>Navigation</source>
        <translation>Навигација</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="808"/>
        <source>Filter</source>
        <translation>Филтер</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="825"/>
        <source>Image</source>
        <translation>Слика</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="871"/>
        <source>Initializing...</source>
        <translation>Покрећем...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="885"/>
        <source>File System</source>
        <translation>Фајл систем</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="922"/>
        <source>Bookmarks</source>
        <translation>Картице</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="945"/>
        <source>Tags</source>
        <translation>Ознаке</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1044"/>
        <source>&lt;p&gt;Image viewer and organizer&lt;/p&gt;</source>
        <translation>Прегледач и организатор слика</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1046"/>
        <source>Home page</source>
        <translation>Почетна страница</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1047"/>
        <source>Bug reports</source>
        <translation>Пријави грешке</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1104"/>
        <location filename="../mainwindow.cpp" line="1330"/>
        <location filename="../mainwindow.cpp" line="1638"/>
        <location filename="../mainwindow.cpp" line="1651"/>
        <location filename="../mainwindow.cpp" line="1761"/>
        <location filename="../mainwindow.cpp" line="1842"/>
        <location filename="../mainwindow.cpp" line="1902"/>
        <location filename="../mainwindow.cpp" line="2703"/>
        <location filename="../mainwindow.cpp" line="2983"/>
        <location filename="../mainwindow.cpp" line="2989"/>
        <location filename="../mainwindow.cpp" line="3006"/>
        <location filename="../mainwindow.cpp" line="3108"/>
        <location filename="../mainwindow.cpp" line="3164"/>
        <location filename="../mainwindow.cpp" line="3175"/>
        <location filename="../mainwindow.cpp" line="3235"/>
        <location filename="../mainwindow.cpp" line="3265"/>
        <location filename="../mainwindow.cpp" line="3304"/>
        <location filename="../mainwindow.cpp" line="3338"/>
        <location filename="../mainwindow.cpp" line="3349"/>
        <source>Error</source>
        <translation>Грешка</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1104"/>
        <source>Failed to start external application.</source>
        <translation>Грешка при покретању екстерне апликације.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1128"/>
        <source>Invalid selection.</source>
        <translation>Неваљала селекција.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1330"/>
        <source>Failed to copy or move image.</source>
        <translation>Неуспело копирање или померање слике.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1384"/>
        <source>Minimum zoom</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1390"/>
        <location filename="../mainwindow.cpp" line="1408"/>
        <source>Zoom %1%</source>
        <translation>Уближи %1%</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1402"/>
        <source>Maximum zoom</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1416"/>
        <source>Zoom Reset</source>
        <translation>Зум враћен</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1431"/>
        <source>Zoom Locked</source>
        <translation>Зум закључан</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1433"/>
        <source>Zoom Unlocked</source>
        <translation>Зум откључан</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1442"/>
        <source>Transformations Locked</source>
        <translation>Трансформације закључане</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1447"/>
        <source>Transformations Unlocked</source>
        <translation>Трансформације откључане</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1459"/>
        <location filename="../mainwindow.cpp" line="1468"/>
        <location filename="../mainwindow.cpp" line="1525"/>
        <location filename="../mainwindow.cpp" line="1534"/>
        <source>Rotation %1°</source>
        <translation>Ротација %1°</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2703"/>
        <source>Failed to open file &quot;%1&quot;, file not found.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source></source>
        <translation></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1475"/>
        <source>Flipped Vertically</source>
        <translation>Обрнуто вертикално</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1475"/>
        <source>Unflipped Vertically</source>
        <translation>Необрнуто вертикално</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1482"/>
        <source>Flipped Horizontally</source>
        <translation>Обрнуто хоризонтално</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1482"/>
        <source>Unflipped Horizontally</source>
        <translation>Необрнуто хоризонтално</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1507"/>
        <location filename="../mainwindow.cpp" line="1798"/>
        <source>No selection</source>
        <translation>Без селекције</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1578"/>
        <source>Mirroring Disabled</source>
        <translation>Пресликавање искључено</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1585"/>
        <source>Mirroring: Dual</source>
        <translation>Пресликавање двоструко</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1592"/>
        <source>Mirroring: Triple</source>
        <translation>Пресликавање троструко</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1599"/>
        <source>Mirroring: Dual Vertical</source>
        <translation>Пресликавање двоструко вертикално</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1606"/>
        <source>Mirroring: Quad</source>
        <translation>Пресликавање четвероструко</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1638"/>
        <source>Can not copy or move to </source>
        <translation>Немогуће копирати или померити у </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1651"/>
        <source>Can not copy or move to the same folder</source>
        <translation>Немогуће копирати или померити у исту фасциклу</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1675"/>
        <location filename="../mainwindow.cpp" line="3027"/>
        <source>Copied</source>
        <translation>Копирано</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1675"/>
        <location filename="../mainwindow.cpp" line="3027"/>
        <source>Moved</source>
        <translation>Померено</translation>
    </message>
    <message numerus="yes">
        <location filename="../mainwindow.cpp" line="1676"/>
        <location filename="../mainwindow.cpp" line="1870"/>
        <location filename="../mainwindow.cpp" line="3028"/>
        <source>%n image(s)</source>
        <translation>
            <numerusform>%n слика</numerusform>
            <numerusform>%n слике</numerusform>
            <numerusform>%n слика</numerusform>
        </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1739"/>
        <source>Permanently delete</source>
        <translation>Трајно избриши</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1740"/>
        <source>Delete image</source>
        <translation>Избриши слику</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1744"/>
        <location filename="../mainwindow.cpp" line="1811"/>
        <location filename="../mainwindow.cpp" line="3289"/>
        <source>Yes</source>
        <translation>Да</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1745"/>
        <location filename="../mainwindow.cpp" line="1812"/>
        <location filename="../mainwindow.cpp" line="3290"/>
        <source>Cancel</source>
        <translation>Откажи</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1758"/>
        <source>Deleted </source>
        <translation>Избрисано</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1761"/>
        <source>Failed to delete image</source>
        <translation>Неуспело брисање слике</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1806"/>
        <source>Permanently delete selected images?</source>
        <translation>Трајно избриши одабране слике?</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1807"/>
        <source>Delete images</source>
        <translation>Избриши слике</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1842"/>
        <source>Failed to delete image.</source>
        <translation>Неуспело брисање слике.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1870"/>
        <source>Deleted</source>
        <translation>Избрисано</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1902"/>
        <source>Invalid Path:</source>
        <translation>Неваљала путања:</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2216"/>
        <source>Viewer</source>
        <translation>Прегледач</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2232"/>
        <source>Docks and Toolbars</source>
        <translation>Сидрене и алатне траке</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2554"/>
        <source>No images</source>
        <translation>Нема слика</translation>
    </message>
    <message>
        <source>Failed to open file &quot;%1&quot;: file not found.</source>
        <translation type="vanished">неуспело отварање фајла &quot;%1&quot;: фајл није пронађен.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2718"/>
        <source>Slide show stopped</source>
        <translation>Слајд приказ обустављен</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2745"/>
        <source>Stop Slide Show</source>
        <translation>Обустани слајд приказ</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2746"/>
        <source>Slide show started</source>
        <translation>Слајд приказ почет</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2983"/>
        <source>Can not move or copy images to this folder.</source>
        <translation>Немогуће померити или копирати слике у ову фасциклу.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2989"/>
        <source>Destination folder is same as source.</source>
        <translation>Одредишна фасцикла је иста као и почетна.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2997"/>
        <source>Move &quot;%1&quot; to &quot;%2&quot;?</source>
        <translation>Помери &quot;%1&quot; у &quot;%2&quot;?</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2998"/>
        <source>Move folder</source>
        <translation>Помери фасциклу</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="3006"/>
        <source>Failed to move folder.</source>
        <translation>Неуспело померање фасцикле.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="3008"/>
        <source>Folder moved</source>
        <translation>Фасцикла померена</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="3108"/>
        <source>Failed to open folder:</source>
        <translation>неуспело отварање фасцикле:</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="3140"/>
        <source>Duplicate images in %1</source>
        <translation>Дупле слике у %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="3153"/>
        <source>New name:</source>
        <translation>Ново име:</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="3164"/>
        <location filename="../mainwindow.cpp" line="3338"/>
        <source>Invalid name entered.</source>
        <translation>Неважеће име унесено.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="3175"/>
        <source>Failed to rename folder.</source>
        <translation>Неуспело преименовање фасцикле.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="3208"/>
        <source>Invalid selection</source>
        <translation>Неваљала селекција</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="3220"/>
        <source>Rename Image</source>
        <translation>Преименуј слику</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="3222"/>
        <source>Enter a new name for &quot;%1&quot;:</source>
        <translation>Унеси ново име за &quot;%1&quot;:</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="3235"/>
        <source>No name entered.</source>
        <translation>Име није унесено.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="3265"/>
        <source>Failed to rename image.</source>
        <translation>Неуспело преименовање слике.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="3281"/>
        <source>Permanently delete &quot;%1&quot; and all of its contents?</source>
        <translation>Трајно Избриши &quot;%1&quot; и сав садржај?</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="3285"/>
        <source>Delete folder</source>
        <translation>Избриши фасциклу</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="3304"/>
        <source>Failed to delete folder.</source>
        <translation>Неуспело брисање фасцикле.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="3308"/>
        <source>Removed &quot;%1&quot;</source>
        <translation>Уклоњен &quot;%1&quot;</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="3326"/>
        <source>New Sub folder</source>
        <translation>Нова под-фасцикла</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="3327"/>
        <source>New folder name:</source>
        <translation>Ново име фасцикле:</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="3349"/>
        <source>Failed to create new folder.</source>
        <translation>Неуспело прављење нове фасцикле.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="3354"/>
        <source>Created &quot;%1&quot;</source>
        <translation>Направљен &quot;%1&quot;</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="3395"/>
        <source>Warning</source>
        <translation>Пажња</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="3395"/>
        <source>Cannot perform action with temporary image.</source>
        <translation>Немогуће извести акцију са привременом сликом.</translation>
    </message>
</context>
<context>
    <name>ProgressDialog</name>
    <message>
        <location filename="../dialogs.cpp" line="1555"/>
        <source>Cancel</source>
        <translation>Откажи</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Usage: phototonic [FILE or DIRECTORY]...</source>
        <translation type="vanished">Користи овако: phototonic [ФАЈЛ или ФАСЦИКЛА]...</translation>
    </message>
</context>
<context>
    <name>ResizeDialog</name>
    <message>
        <location filename="../dialogs.cpp" line="813"/>
        <source>Scale Image</source>
        <translation>Промени величину слике</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="825"/>
        <source>Scale</source>
        <translatorcomment>Можа има болја јединствена реч</translatorcomment>
        <translation>Увећај/Смањи</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="829"/>
        <source>Cancel</source>
        <translation>Откажи</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="845"/>
        <source>Original size:</source>
        <translation>Оригинална величина:</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="848"/>
        <source>Width:</source>
        <translation>Ширина:</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="849"/>
        <source>Height:</source>
        <translation>Висина:</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="850"/>
        <source>Units:</source>
        <translation>Јединице:</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="852"/>
        <source>New size:</source>
        <translation>Нова величина:</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="855"/>
        <source>Pixels</source>
        <translation>Пиксели</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="857"/>
        <source>Percent</source>
        <translation>Постотак</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="862"/>
        <source>Lock aspect ratio</source>
        <translation>Закључај омер</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../dialogs.cpp" line="270"/>
        <source>Preferences</source>
        <translation>Поставке</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="275"/>
        <source>Fit Large Images</source>
        <translation>Прилагоди велике слике</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="276"/>
        <location filename="../dialogs.cpp" line="293"/>
        <source>Disable</source>
        <translation>Искључено</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="277"/>
        <location filename="../dialogs.cpp" line="294"/>
        <source>By width or height</source>
        <translation>По ширини или висини</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="278"/>
        <location filename="../dialogs.cpp" line="295"/>
        <source>By width</source>
        <translation>По ширини</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="279"/>
        <location filename="../dialogs.cpp" line="296"/>
        <source>By height</source>
        <translation>По висини</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="280"/>
        <location filename="../dialogs.cpp" line="297"/>
        <source>Stretch disproportionately</source>
        <translation>Развуци диспропорционално</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="292"/>
        <source>Fit Small Images</source>
        <translation>Прилагоди мање слике</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="309"/>
        <location filename="../dialogs.cpp" line="371"/>
        <source>Background color:</source>
        <translation>Боја позадине:</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="323"/>
        <source>Exit instead of closing, when image is loaded from command line</source>
        <translation>Напусти уместо затварања када је учитана слика из командне линије</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="327"/>
        <source>Wrap image list when reaching last or first image</source>
        <translatorcomment>Ово дефинитивно поправити</translatorcomment>
        <translation>Умотај листу слика при крају</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="331"/>
        <source>Default quality when saving images:</source>
        <translation>Стандардни квалитет при снимању слика:</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="341"/>
        <source>Enable GIF animation</source>
        <translation>Укључи GIF анимације</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="345"/>
        <source>Rotate image according to Exif orientation</source>
        <translation>Ротирај слике према Exif оријентацији</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="349"/>
        <source>Show image file name in viewer</source>
        <translation>Прикажи име слике у прегледачу</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="383"/>
        <source>Label color:</source>
        <translation>Boja natpisa:</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="395"/>
        <source>Background image:</source>
        <translation>Позадинска слика:</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="414"/>
        <source>Add space between thumbnails:</source>
        <translation>Додај размак између минијатурних приказа:</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="425"/>
        <source>Show original size of images smaller than the thumbnail size</source>
        <translatorcomment>Поправити</translatorcomment>
        <translation>Прикажи оригиналну величину слика које су манње од минијатурне величине</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="429"/>
        <source>Number of thumbnail pages to read ahead:</source>
        <translation>Број страница минијатурних слика да се учита унапред:</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="438"/>
        <source>Rotate thumbnails according to Exif orientation</source>
        <translation>Ротирај минијатурне слике по Exif оријентацији</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="452"/>
        <source>Delay between slides in seconds:</source>
        <translation>Размак између слајдова у секундама:</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="462"/>
        <source>Show random images</source>
        <translation>Прикажи насумичне слике</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="472"/>
        <source>Startup folder</source>
        <translation>Почетна фасцикла</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="474"/>
        <source>Default, or specified by command line argument</source>
        <translatorcomment>Поправити</translatorcomment>
        <translation>Стандардни, или командном линиjom одређени аргумент</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="475"/>
        <source>Remember last</source>
        <translation>Запамти последњу</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="476"/>
        <source>Specify:</source>
        <translation>Одреди:</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="523"/>
        <source>Swap mouse left-click and middle-click actions</source>
        <translation>Замени акције левог и средњег клика мишем</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="527"/>
        <source>Delete confirmation</source>
        <translation>Потврда за брисање</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="531"/>
        <source>Keyboard Shortcuts</source>
        <translation>Кратице тастатуре</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="545"/>
        <source>OK</source>
        <translation>Уреду</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="550"/>
        <source>Cancel</source>
        <translation>Откажи</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="562"/>
        <source>Viewer</source>
        <translation>Прегледач</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="566"/>
        <source>Thumbnails</source>
        <translation>Минијатурни приказ</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="570"/>
        <source>Slide Show</source>
        <translation>Слајд приказ</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="574"/>
        <source>General</source>
        <translation>Опћенито</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="674"/>
        <source>Choose Startup Folder</source>
        <translation>Изабери почетну фасциклу</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="681"/>
        <source>Open File</source>
        <translation>Отвори фајл</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="682"/>
        <source>Images</source>
        <translation>Слике</translation>
    </message>
</context>
<context>
    <name>ShortcutsTable</name>
    <message>
        <location filename="../dialogs.cpp" line="170"/>
        <source>Action</source>
        <translation>Акција</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="171"/>
        <source>Shortcut</source>
        <translation>Пречице</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="185"/>
        <source>Delete shortcut</source>
        <translation>Избриши пречицу</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="227"/>
        <location filename="../dialogs.cpp" line="239"/>
        <source>Set shortcut</source>
        <translation>Постави пречицу</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="228"/>
        <source>&quot;%1&quot; is reserved for shortcuts to external applications.</source>
        <translatorcomment>Дефинитивно поправити</translatorcomment>
        <translation>&quot;%1&quot; је обрнуто за пречице код екстерних апликација.</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="240"/>
        <source>&quot;%1&quot; is already assigned to &quot;%2&quot; action.</source>
        <translatorcomment>Поправити</translatorcomment>
        <translation>&quot;%1&quot; је већ употребљено за &quot;%2&quot; акцију.</translation>
    </message>
</context>
<context>
    <name>ThumbView</name>
    <message>
        <location filename="../thumbview.cpp" line="245"/>
        <source>General</source>
        <translation>Уопштено</translation>
    </message>
    <message>
        <location filename="../thumbview.cpp" line="247"/>
        <source>File name</source>
        <translation>Име фајла</translation>
    </message>
    <message>
        <location filename="../thumbview.cpp" line="251"/>
        <source>Location</source>
        <translation>Локација</translation>
    </message>
    <message>
        <location filename="../thumbview.cpp" line="255"/>
        <source>Size</source>
        <translation>Величина</translation>
    </message>
    <message>
        <location filename="../thumbview.cpp" line="259"/>
        <source>Modified</source>
        <translation>Модифициран</translation>
    </message>
    <message>
        <location filename="../thumbview.cpp" line="264"/>
        <source>Format</source>
        <translation>формат</translation>
    </message>
    <message>
        <location filename="../thumbview.cpp" line="268"/>
        <source>Resolution</source>
        <translation>Резолуција</translation>
    </message>
    <message>
        <location filename="../thumbview.cpp" line="274"/>
        <source>Megapixel</source>
        <translation>Мегапиксел</translation>
    </message>
    <message>
        <location filename="../thumbview.cpp" line="282"/>
        <source>Error</source>
        <translation>Грешка</translation>
    </message>
    <message>
        <location filename="../thumbview.cpp" line="297"/>
        <source>Selected %1 of%2</source>
        <translation>Изабрано %1 од %2</translation>
    </message>
    <message numerus="yes">
        <location filename="../thumbview.cpp" line="299"/>
        <source> %n image(s)</source>
        <translation>
            <numerusform>%n слика</numerusform>
            <numerusform>%n слике</numerusform>
            <numerusform>%n слика</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location filename="../thumbview.cpp" line="463"/>
        <location filename="../thumbview.cpp" line="684"/>
        <location filename="../thumbview.cpp" line="685"/>
        <source>%n image(s)</source>
        <translation>
            <numerusform>%n слика</numerusform>
            <numerusform>%n слике</numerusform>
            <numerusform>%n слика</numerusform>
        </translation>
    </message>
    <message>
        <location filename="../thumbview.cpp" line="465"/>
        <source>No images</source>
        <translation>Нема слика</translation>
    </message>
    <message>
        <location filename="../thumbview.cpp" line="582"/>
        <source>Searching duplicate images...</source>
        <translation>Тражим дупле слике...</translation>
    </message>
    <message>
        <location filename="../thumbview.cpp" line="683"/>
        <source>Scanned %1, displaying %2 (%3 and %4)</source>
        <translation>Скениран %1, приказујем %2 (%3 и %4)</translation>
    </message>
    <message numerus="yes">
        <location filename="../thumbview.cpp" line="686"/>
        <source>%n original(s)</source>
        <translation>
            <numerusform>%n оригинал</numerusform>
            <numerusform>%n оригинала</numerusform>
            <numerusform>%n оригинала</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location filename="../thumbview.cpp" line="687"/>
        <source>%n duplicate(s)</source>
        <translation>
            <numerusform>%n дупликат</numerusform>
            <numerusform>%n дупликата</numerusform>
            <numerusform>%n дупликата</numerusform>
        </translation>
    </message>
</context>
</TS>
